==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1PersistentVolumeClaimVolumeSourceFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1PersistentVolumeClaimVolumeSourceFluentImpl<A extends V1PersistentVolumeClaimVolumeSourceFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1PersistentVolumeClaimVolumeSourceFluent<A>{

    private String claimName;
    private Boolean readOnly;

    public V1PersistentVolumeClaimVolumeSourceFluentImpl(){
    }
    public V1PersistentVolumeClaimVolumeSourceFluentImpl(V1PersistentVolumeClaimVolumeSource instance){
            this.withClaimName(instance.getClaimName());

            this.withReadOnly(instance.isReadOnly());

    }

    public String getClaimName(){
            return this.claimName;
    }

    public A withClaimName(String claimName){
            this.claimName=claimName; return (A) this;
    }

    public Boolean hasClaimName(){
            return this.claimName != null;
    }

    public Boolean isReadOnly(){
            return this.readOnly;
    }

    public A withReadOnly(Boolean readOnly){
            this.readOnly=readOnly; return (A) this;
    }

    public Boolean hasReadOnly(){
            return this.readOnly != null;
    }

    public A withNewReadOnly(boolean arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    public A withNewReadOnly(String arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1PersistentVolumeClaimVolumeSourceFluentImpl that = (V1PersistentVolumeClaimVolumeSourceFluentImpl) o;
            if (claimName != null ? !claimName.equals(that.claimName) :that.claimName != null) return false;
            if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1PersistentVolumeClaimVolumeSourceFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1PersistentVolumeClaimVolumeSourceFluentImpl<A extends V1PersistentVolumeClaimVolumeSourceFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1PersistentVolumeClaimVolumeSourceFluent<A>{

    private String claimName;
    private Boolean readOnly;

    public V1PersistentVolumeClaimVolumeSourceFluentImpl(){
    }
    public V1PersistentVolumeClaimVolumeSourceFluentImpl(V1PersistentVolumeClaimVolumeSource instance){
            this.withClaimName(instance.getClaimName());

            this.withReadOnly(instance.isReadOnly());

    }

    public String getClaimName(){
            return this.claimName;
    }

    public A withClaimName(String claimName){
            this.claimName=claimName; return (A) this;
    }

    public Boolean hasClaimName(){
            return this.claimName != null;
    }

    public A withNewClaimName(String arg1){
            return (A)withClaimName(new String(arg1));
    }

    public A withNewClaimName(StringBuilder arg1){
            return (A)withClaimName(new String(arg1));
    }

    public A withNewClaimName(StringBuffer arg1){
            return (A)withClaimName(new String(arg1));
    }

    public Boolean isReadOnly(){
            return this.readOnly;
    }

    public A withReadOnly(Boolean readOnly){
            this.readOnly=readOnly; return (A) this;
    }

    public Boolean hasReadOnly(){
            return this.readOnly != null;
    }

    public A withNewReadOnly(String arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    public A withNewReadOnly(boolean arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1PersistentVolumeClaimVolumeSourceFluentImpl that = (V1PersistentVolumeClaimVolumeSourceFluentImpl) o;
            if (claimName != null ? !claimName.equals(that.claimName) :that.claimName != null) return false;
            if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
            return true;
    }




}
